pub struct SurfaceDataPreview;Trait Implementations
Sourceimpl AssetPreviewGenerator for SurfaceDataPreview
impl AssetPreviewGenerator for SurfaceDataPreview
Sourcefn generate_scene(
&mut self,
resource: &UntypedResource,
_resource_manager: &ResourceManager,
scene: &mut Scene,
_preview_camera: Handle<Camera>,
) -> Handle<Node>
fn generate_scene( &mut self, resource: &UntypedResource, _resource_manager: &ResourceManager, scene: &mut Scene, _preview_camera: Handle<Camera>, ) -> Handle<Node>
Generates a scene, that will be used in the asset browser. Not all assets could provide
sensible scene for themselves, in this case this method should return
Handle::NONE.Sourcefn generate_preview(
&mut self,
resource: &UntypedResource,
engine: &mut Engine,
) -> Option<AssetPreviewTexture>
fn generate_preview( &mut self, resource: &UntypedResource, engine: &mut Engine, ) -> Option<AssetPreviewTexture>
Generates a preview image for an asset. For example, in case of prefabs, it will be the
entire prefab content rendered to an image. In case of sounds it will be its waveform, and
so on.
Sourcefn simple_icon(
&self,
_resource: &UntypedResource,
_resource_manager: &ResourceManager,
) -> Option<TextureResource>
fn simple_icon( &self, _resource: &UntypedResource, _resource_manager: &ResourceManager, ) -> Option<TextureResource>
Returns simplified icon for assets, usually it is just a picture.