pub struct BrushMacroCellContext {
pub brush: TileMapBrushResource,
pub settings: Option<UntypedResource>,
pub cell: Option<TileDefinitionHandle>,
}Expand description
Context for methods of BrushMacro that are specific to a single brush cell,
such as adding a new cell to the macro, removing a cell, or building the widgets
for editing the settings of a cell.
Fields
brush: TileMapBrushResourceThe brush that has an instance of the macro.
settings: Option<UntypedResource>The configuration for an instance of the macro.
cell: Option<TileDefinitionHandle>The currently selected brush cell, or None if no cell is selected.
Implementations
Sourceimpl BrushMacroCellContext
impl BrushMacroCellContext
Sourcepub fn settings<T>(&self) -> Option<Resource<T>>
pub fn settings<T>(&self) -> Option<Resource<T>>
A typed reference to the configuration resource.
Sourcepub fn brush(&self) -> ResourceDataRef<'_, TileMapBrush>
pub fn brush(&self) -> ResourceDataRef<'_, TileMapBrush>
A reference to the brush’s data.
Sourcepub fn tile_set(&self) -> Option<TileSetFromBrush<'_>>
pub fn tile_set(&self) -> Option<TileSetFromBrush<'_>>
The tile set resource taken from the brush.