pub struct MacroCellSetListRef(/* private fields */);Expand description
An Arc Mutex reference to a MacroCellSetList which allows
shared access to the positions of cells which are currently involved
in some macro. This is only used in the TileSetEditor, but it needs
to be shared with the PaletteWidget so that the widget can
render a highlight at those positions.
Implementations
Sourceimpl MacroCellSetListRef
impl MacroCellSetListRef
Sourcepub fn new(list: MacroCellSetList) -> Self
pub fn new(list: MacroCellSetList) -> Self
Create a new reference and assign it to point to the given set of cells.
Sourcepub fn lock(&self) -> MutexGuard<'_, RawMutex, MacroCellSetList>
pub fn lock(&self) -> MutexGuard<'_, RawMutex, MacroCellSetList>
Access the set of cells.