pub struct MacroPropertyField { /* private fields */ }Expand description
A field that allows the user to choose a property from a TileSet.
The property is represented as UUID internally, but the user
is given a dropdown list of property names.
Implementations
Sourceimpl MacroPropertyField
impl MacroPropertyField
Sourcepub fn new(
widget_builder: WidgetBuilder,
label: String,
prop_type: TileSetPropertyType,
value: Option<&Uuid>,
tile_set: Option<&TileSet>,
ctx: &mut BuildContext<'_>,
) -> Self
pub fn new( widget_builder: WidgetBuilder, label: String, prop_type: TileSetPropertyType, value: Option<&Uuid>, tile_set: Option<&TileSet>, ctx: &mut BuildContext<'_>, ) -> Self
-label: The string that names this field on the left side.
-prop_type: The type of value that the property is expected to hold.
Only properties that match this type will be listed.
-value: The UUID of the currently selected property, or None.
-tile_set: The tile set to search for properties.
Sourcepub fn sync(
&self,
value: Option<&Uuid>,
tile_set: Option<&TileSet>,
ui: &mut UserInterface,
)
pub fn sync( &self, value: Option<&Uuid>, tile_set: Option<&TileSet>, ui: &mut UserInterface, )
Update the field’s widgets to reflect any changes in the tile set.
-value: The UUID of the currently selected property.
Sourcepub fn on_ui_message(
&mut self,
tile_set: &TileSet,
message: &UiMessage,
ui: &mut UserInterface,
)
pub fn on_ui_message( &mut self, tile_set: &TileSet, message: &UiMessage, ui: &mut UserInterface, )
Handle the given message, which might be relevant to some widget in the field.