pub struct MacroPropertyValueField { /* private fields */ }Expand description
A field that allows the user to choose a property value from a TileSet.
The property is represented as a TileSetPropertyValueElement internally, but the user
is given a dropdown list of value names if possible.
Implementations
Sourceimpl MacroPropertyValueField
impl MacroPropertyValueField
Sourcepub fn new(
widget_builder: WidgetBuilder,
label: String,
value: TileSetPropertyValueElement,
prop: Option<&TileSetPropertyLayer>,
ctx: &mut BuildContext<'_>,
) -> Self
pub fn new( widget_builder: WidgetBuilder, label: String, value: TileSetPropertyValueElement, prop: Option<&TileSetPropertyLayer>, ctx: &mut BuildContext<'_>, ) -> Self
-label: The string that names this field on the left side.
-value: The current value of the property. This determines the type of the field,
and cannot be changed later.
-prop: The property of the tile set. This is used to build a dropdown list of
named values.
Sourcepub fn sync(
&self,
value: TileSetPropertyValueElement,
prop: Option<&TileSetPropertyLayer>,
ui: &mut UserInterface,
)
pub fn sync( &self, value: TileSetPropertyValueElement, prop: Option<&TileSetPropertyLayer>, ui: &mut UserInterface, )
Update the field’s widgets to reflect any changes in the tile set.
-value: The UUID of the currently selected property. This will be ignored
if its type does not match the type of the field.
-prop: The property of the tile set. This is used to build a dropdown list of
named values.
Sourcepub fn on_ui_message(
&mut self,
prop: Option<&TileSetPropertyLayer>,
message: &UiMessage,
ui: &mut UserInterface,
)
pub fn on_ui_message( &mut self, prop: Option<&TileSetPropertyLayer>, message: &UiMessage, ui: &mut UserInterface, )
Handle the given message, which might be relevant to some widget in the field.