pub struct TileDrawState { /* private fields */ }Expand description
This is the state that is shared between the plugin, the palette widgets, the interaction mode, and the control panel, so that they can all be synchronized with whatever editing operation the user is currently performing.
Implementations
Sourceimpl TileDrawState
impl TileDrawState
Sourcepub fn is_active_editor(&self, editor: &Arc<Mutex<dyn TileEditor>>) -> bool
pub fn is_active_editor(&self, editor: &Arc<Mutex<dyn TileEditor>>) -> bool
True if the given editor is the active editor.
Sourcepub fn set_visible_collider(&mut self, uuid: Uuid, visible: bool)
pub fn set_visible_collider(&mut self, uuid: Uuid, visible: bool)
Set whether the given collider is visible.
Sourcepub fn has_selection(&self) -> bool
pub fn has_selection(&self) -> bool
True if the current selection is not empty
Sourcepub fn selection_palette(&self) -> Handle<UiNode>
pub fn selection_palette(&self) -> Handle<UiNode>
The handle of the palette widget that is currently being used to select tiles, or else Handle::NONE.
Sourcepub fn selection_node(&self) -> Handle<Node>
pub fn selection_node(&self) -> Handle<Node>
The handle of the tile map node that is currently being used to select tiles, or else Handle::NONE.
Sourcepub fn set_palette(&mut self, handle: Handle<UiNode>)
pub fn set_palette(&mut self, handle: Handle<UiNode>)
Some PaletteWidget is being used to select tiles.
Sourcepub fn selection_positions(&self) -> &FxHashSet<Vector2<i32>>
pub fn selection_positions(&self) -> &FxHashSet<Vector2<i32>>
The positions of the currently selected tiles.
Sourcepub fn selection_positions_mut(&mut self) -> &mut FxHashSet<Vector2<i32>>
pub fn selection_positions_mut(&mut self) -> &mut FxHashSet<Vector2<i32>>
The positions of the currently selected tiles.
Sourcepub fn on_selection_changed(&mut self)
pub fn on_selection_changed(&mut self)
Perform necessary cleanup when the selected tiles are changed.
Sourcepub fn clear_selection(&mut self)
pub fn clear_selection(&mut self)
Set selection to nothing.
Sourcepub fn update_stamp<F>(
&mut self,
book: Option<TileBook>,
tile_set: Option<TileSetResource>,
tile_handle: F,
)
pub fn update_stamp<F>( &mut self, book: Option<TileBook>, tile_set: Option<TileSetResource>, tile_handle: F, )
Update the stamp stored within this state to reflect the current selection
and tile set. The given tile_handle function is used to determine the handles
for each selection position.