pub struct GraphSelection {
pub nodes: Vec<Handle<Node>>,
}Fields
nodes: Vec<Handle<Node>>Implementations
Sourceimpl GraphSelection
impl GraphSelection
pub fn from_list(nodes: Vec<Handle<Node>>) -> Self
Sourcepub fn single_or_empty(node: Handle<Node>) -> Self
pub fn single_or_empty(node: Handle<Node>) -> Self
Creates new selection as single if node handle is not none, and empty if it is.
Sourcepub fn insert_or_exclude(&mut self, handle: Handle<Node>)
pub fn insert_or_exclude(&mut self, handle: Handle<Node>)
Adds new selected node, or removes it if it is already in the list of selected nodes.
pub fn contains(&self, handle: Handle<Node>) -> bool
pub fn nodes(&self) -> &[Handle<Node>]
pub fn extend(&mut self, other: &GraphSelection)
pub fn root_nodes(&self, graph: &Graph) -> Vec<Handle<Node>>
pub fn global_rotation_position( &self, graph: &Graph, ) -> Option<(UnitQuaternion<f32>, Vector3<f32>)>
pub fn offset(&self, graph: &mut Graph, offset: Vector3<f32>)
pub fn rotate(&self, graph: &mut Graph, rotation: UnitQuaternion<f32>)
pub fn scale(&self, graph: &mut Graph, scale: Vector3<f32>)
pub fn local_positions(&self, graph: &Graph) -> Vec<Vector3<f32>> ⓘ
pub fn local_rotations(&self, graph: &Graph) -> Vec<UnitQuaternion<f32>> ⓘ
pub fn local_scales(&self, graph: &Graph) -> Vec<Vector3<f32>> ⓘ